@@ -7,11 +7,9 @@
 # 3rd party packages
 
 # Local source
-from domain.cost.strategy import IErrorStrategy
-from domain.cost.factory import ErrorFactory
+from parametrization_clean.domain.cost.strategy import IErrorStrategy
 
 
-@ErrorFactory.register('reax_error')
 class ReaxError(IErrorStrategy):
 
     @staticmethod
