@@ -8,13 +8,11 @@ import random
 
 
 # Local source
-from domain.crossover.strategy import ICrossoverStrategy
-from domain.crossover.factory import CrossoverFactory
-from domain.individual import Individual
-from domain.root_individual import RootIndividual
+from parametrization_clean.domain.crossover.strategy import ICrossoverStrategy
+from parametrization_clean.domain.individual import Individual
+from parametrization_clean.domain.root_individual import RootIndividual
 
 
-@CrossoverFactory.register('two_point')
 class TwoPointCross(ICrossoverStrategy):
 
     @staticmethod
