@@ -7,13 +7,11 @@ import random
 
 
 # Local source
-from domain.mutation.strategy import IMutationStrategy
-from domain.mutation.factory import MutationFactory
-from domain.individual import Individual
-from domain.root_individual import RootIndividual
+from parametrization_clean.domain.mutation.strategy import IMutationStrategy
+from parametrization_clean.domain.individual import Individual
+from parametrization_clean.domain.root_individual import RootIndividual
 
 
-@MutationFactory.register('nakata')
 class NakataMutate(IMutationStrategy):
 
     @staticmethod
