@@ -13,8 +13,8 @@ import abc
 
 
 # Local source
-from domain.individual import Individual
-from domain.root_individual import RootIndividual
+from parametrization_clean.domain.individual import Individual
+from parametrization_clean.domain.root_individual import RootIndividual
 
 
 class IMutationStrategy(metaclass=abc.ABCMeta):
