@@ -4,8 +4,8 @@
 # 3rd party packages
 
 # Local source
-from domain.selection.factory import SelectionFactory
-from domain.selection.tournament import TournamentSelect
+from parametrization_clean.domain.selection.factory import SelectionFactory
+from parametrization_clean.domain.selection.tournament import TournamentSelect
 
 
 def test_get_tournament():
